      program gprobdens
c----------------------------------------------------------------------
c
c Calculates probability density profiles from an array of
c data and their uncertainties.  
c
c Input:  filename.dat, two column file with x 1(2)sigma as the 
c         two columns.
c
c Output:  filename.txt, three column file with x, PDF, CPDF where
c          x is the data, PDF is the probability density function,
c          and CPDF is the cumulative probability density function.
c
c Program written by Oscar Lovera and passed to E. Young, April 2012.
c Modified by E. Young since.
c
c
c
	PARAMETER(NPTS=500000,NG=1000000,EPS=0.1)
c	PARAMETER(NPTS=10000,NG=1000000,EPS=0.1,ngd=16384)
	real data1(NPTS),sig(npts)

c	EXTERNAL FUNC
        common x0,w
        character*9  tab1,yes*1
        character*30 fname
	  idum = -1
	  NPG = 100
c
        Print *,' '
        Print *,'CALCULATES PROBABILITY DENSITY PROFILE FOR' 
        Print *,'INPUT DATA AND ERROR IN DATA'
        Print *,' '
1	  print *,'Enter sample file name (stop to end read)'
	  read(*,5) fname
5       format(A)	  
	  if(fname(1:4).eq.'stop')goto 18
      open(unit=10,file=fname,status='old')
      open(unit=22,file=TRIM(fname) //'.prob')

c      Print *,'Sigma Error selection, 1.0 = 1sig  2.0 = 2sig:'
c	Read *,sigfactor
      sigfactor=1.0 

	Print *, 'Range of total distribution...'
	Print *, 'Enter minimum x value (xmin):'
	read *,xmin
	Print *, 'Enter maximum x value (xmax):'
	read *,xmax
	if(xmax-xmin.le.400)then
	    ngd = 2048
	else
	    ngd = 16384
	endif
c	xmin = 0.
c	xmax = 3000.
c
          print*,'Reading data...'
          n1=1 
          print *,'N = ',n1
10        read(10,*,end=12) data1(n1),sig(n1)
          print *,'input: ',data1(n1),sig(n1)
          sig(n1) = sig(n1)/sigfactor
	    n1=n1+1 
          goto 10
12        print *,'Done reading data.'
          n1 = n1-1
c
          gcum = 0.
	    dx = (xmax-xmin)/ngd
	    xk = xmin	    
14          gd0=0.
	      do j=1,n1
	        gd0=gd0 + gdist(xk,data1(j),sig(j))
	      enddo
	      gd0= gd0/n1
	      gcum = gcum + gd0*dx
	      if(gcum.gt.1.)gcum = 1.
	      write(22,*)xk,gd0,gcum*100.
	      xk= xk + dx
	    if(xk.lt.xmax)goto 14
	     close(22)
      goto 1
18	print *,'finished...look in sampleID.txt'
      stop
	end
c-----------------------------------------------------------------------
	function gdist(x,xval,xerr)
c      implicit double precision (a-h,o-z)
      parameter(pi=3.141592653589793)
         xd=(x-xval)**2
	   gdist = exp(-xd/2./xerr**2)/xerr/sqrt(2.*pi)
      return
      end      


      function name(sname)  
      character fname*30  
      do 10 j=1,10  
        if(fname(j:j).eq.' ')then  
          if(j.eq.1)stop 'name starts with empty space'  
          name = j-1  
          return  
        endif  
        name = 10  
10    continue  
      return  
      end  